function layout(han,par,fun,rel)
%LAYOUT(HAN,PAR,FUN,REL)  arranging plots on a figure
%HAN is a column vector with axes handles. PAR contains parameters
%that are used in arranging the plots. 
%
%FUN is the functionality of the operation with options:
%     'm':   Move to an absolute position
%     'e':     move an Edge to an absolute position
%     'v':     move relatiVely    
%     's':     Scale
%     'd':    set Dimension
%
%REL says relative to which part of the axes the operation should be
%performed with options:
%     'l':    left border
%     'r':   right border
%     'b':  bottom
%     't':   top
%     'x';   center, horizontally
%     'y';  center, vertically
%
%
%PAR, FUN and REL should have either one line or as many lines as HAN.
%PAR, FUN and REL should all have the same number of columns.
%If PAR contains NaN for the operation using that parameter is not performed.
% Note, results can be unexpected for options 'v', 's' and 'd' if 'axis image' 
%is on, or similar, keeping the ratio between widht and height of the plot.
%Giving parameters that result in negative height or width will give an
%error.

%Examples:
 
%layout(h1,[0.5 0.6 0.4 0.3],'mmdd','xbxb');
%Centers horizontally, moves bottom to 0.6 and then sets the size to 0.4
%and 0.4.

%for j=1:3, subs(j)=subplot(1,3,j); end
%layout(subs(:),[-0.1 0.8 0.1]','vsv','tyb');
%shrinks the plots vertically.
%Other options explain themselves


sh=size(han);
sp=size(par);
sr=size(rel);
sf=size(fun);

if sh(2)~=1 | any(~ishandle(han)),
  error('The first input has to be a column vector of axes handles')
end

if sp(2)~=sr(2) | sp(2)~=sf(2),
  error('The last three inputs must have the same number of columns')
end

if (sh(1)~=sp(1) & sp(1)~=1) |  (sh(1)~=sr(1) & sr(1)~=1) |  (sh(1)~=sf(1) &  sf(1)~=1),
  error([     'The last three inputs must have the same number of lines ' 10 ...
	'as the first input or be only one line'])
end


if sh(1)>1,
  if sp(1)==1,
    par=repmat(par,sh(1),1);
  end
  if sr(1)==1,
    rel=repmat(rel,sh(1),1);
  end
  if sf(1)==1,
    fun=repmat(fun,sh(1),1);
  end
end


for i=1:sh(1),
  pos=get(han(i),'position');
  for j=1:sp(2),
    p=par(i,j);
    f=fun(i,j);
    r=rel(i,j);
    if ~isnan(p),
      switch f
	case 'm'	  
	  switch r
	    case 'l'
	      pos(1)=p;
	    case 'r'
	      pos(1)=p-pos(3);
	    case 'b'
	      pos(2)=p;
	    case 't'
	      pos(2)=p-pos(4);
	    case 'x'
	      pos(1)=p-pos(3)/2;
	    case 'y'
	      pos(2)=p-pos(4)/2;
	    otherwise
	      error([ 'Unknown option for relative '''   r  ''' should be  l, r, b, t, x, y'])
	  end	
	  
	  
	case 's'
	  switch r
	    case 'l'
	      pos(3)=p*pos(3);
	    case 'r'
	      pos(1)=pos(1)+pos(3)*(1-p);
	      pos(3)=p*pos(3);
	    case 'b'
	      pos(4)=p*pos(4);
	    case 't'
	      pos(2)=pos(2)+pos(4)*(1-p);
	      pos(4)=p*pos(4);
	    case 'x'
	      pos(1)=pos(1)+pos(3)/2*(1-p);
	      pos(3)=pos(3)*p;
	    case 'y'
	      pos(2)=pos(2)+pos(4)/2*(1-p);
	      pos(4)=pos(4)*p;
	    otherwise
	      error([ 'Unknown option for relative '''   r  ''' should be  l, r, b, t, x, y'])
	  end
	  
	  
	case 'd'
	  switch r
	    case 'l'
	      pos(3)=p;
	    case 'r'
	      pos(1)=pos(1)+pos(3)-p;
	      pos(3)=p;
	    case 'b'
	      pos(4)=p;
	    case 't'
	      pos(2)=pos(2)+pos(4)-p;
	      pos(4)=p;
	    case 'x'
	      pos(1)=pos(1)+pos(3)/2-p/2;
	      pos(3)=p;
	    case 'y'
	      pos(2)=pos(2)+pos(4)/2-p/2;
	      pos(4)=p;	  
	    otherwise
	      error([ 'Unknown option for relative '''   r  ''' should be  l, r, b, t, x, y'])
	  end		
	  
	  
	case 'e'
	  switch r
	    case 'l'
	      pos(3)=pos(3)+pos(1)-p;
	      pos(1)=p;
	    case 'r'
	       pos(3)=p-pos(1);
	    case 'b'
	      pos(4)=pos(4)+pos(2)-p;
	      pos(2)=p;
	    case 't'
	      pos(4)=p-pos(2);
	    case 'x'
	      pos(1)=p-pos(3)/2;
	    case 'y'
	      pos(2)=p-pos(4)/2;
	    otherwise
	      error([ 'Unknown option for relative '''   r  ''' should be  l, r, b, t, x, y'])
	  end
	  
	  
	case 'v'
	  switch r
	    case 'l'
	      pos(3)=pos(3)-p;
	      pos(1)=pos(1)+p;
	    case 'r'
	       pos(3)=pos(3)+p;
	    case 'b'
	      pos(4)=pos(4)-p;
	      pos(2)=pos(2)+p;
	    case 't'
	      pos(4)=pos(4)+p;
	    case 'x'
	      pos(1)=pos(1)+p;
	    case 'y'
	      pos(2)=pos(2)+p;
	    otherwise
	      error([ 'Unknown option for relative '''   r  ''' should be  l, r, b, t, x, y'])
	  end
	  
	otherwise
	  error([ 'Unknown option for function '''   f  ''' should be  m, s, e or  v'])	
      end 
    end
  end
  set(han(i),'position',pos);
end











